@@ -6,15 +6,16 @@ Type annotations for cognito-sync service client.
 Usage::
 
     ```python
-    import boto3
-    from mypy_boto3_cognito_sync import CognitoSyncClient
+    from boto3.session import Session
+    from mypy_boto3_cognito_sync.client import CognitoSyncClient
 
-    client: CognitoSyncClient = boto3.client("cognito-sync")
+    session = Session()
+    client: CognitoSyncClient = session.client("cognito-sync")
     ```
 """
-from typing import Any, Dict, List, Type
+from typing import Any, Dict, Mapping, Sequence, Type
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import PlatformType
 from .type_defs import (
@@ -43,7 +44,7 @@ __all__ = ("CognitoSyncClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -65,24 +66,37 @@ class Exceptions:
     TooManyRequestsException: Type[BotocoreClientError]
 
 
-class CognitoSyncClient:
+class CognitoSyncClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        CognitoSyncClient exceptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#exceptions)
+        """
 
     def bulk_publish(self, *, IdentityPoolId: str) -> BulkPublishResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.bulk_publish)
+        Initiates a bulk publish of all existing datasets for an Identity Pool to the
+        configured stream.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.bulk_publish)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#bulk_publish)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#can_paginate)
         """
 
@@ -90,7 +104,9 @@ class CognitoSyncClient:
         self, *, IdentityPoolId: str, IdentityId: str, DatasetName: str
     ) -> DeleteDatasetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.delete_dataset)
+        Deletes the specific dataset.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.delete_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#delete_dataset)
         """
 
@@ -98,7 +114,9 @@ class CognitoSyncClient:
         self, *, IdentityPoolId: str, IdentityId: str, DatasetName: str
     ) -> DescribeDatasetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.describe_dataset)
+        Gets meta data about a dataset by identity and dataset name.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.describe_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#describe_dataset)
         """
 
@@ -106,7 +124,9 @@ class CognitoSyncClient:
         self, *, IdentityPoolId: str
     ) -> DescribeIdentityPoolUsageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.describe_identity_pool_usage)
+        Gets usage details (for example, data storage) about a particular identity pool.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.describe_identity_pool_usage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#describe_identity_pool_usage)
         """
 
@@ -114,19 +134,24 @@ class CognitoSyncClient:
         self, *, IdentityPoolId: str, IdentityId: str
     ) -> DescribeIdentityUsageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.describe_identity_usage)
+        Gets usage information for an identity, including number of datasets and data
+        usage.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.describe_identity_usage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#describe_identity_usage)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#generate_presigned_url)
         """
 
@@ -134,13 +159,18 @@ class CognitoSyncClient:
         self, *, IdentityPoolId: str
     ) -> GetBulkPublishDetailsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.get_bulk_publish_details)
+        Get the status of the last BulkPublish operation for an identity pool.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.get_bulk_publish_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#get_bulk_publish_details)
         """
 
     def get_cognito_events(self, *, IdentityPoolId: str) -> GetCognitoEventsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.get_cognito_events)
+        Gets the events and the corresponding Lambda functions associated with an
+        identity pool.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.get_cognito_events)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#get_cognito_events)
         """
 
@@ -148,23 +178,29 @@ class CognitoSyncClient:
         self, *, IdentityPoolId: str
     ) -> GetIdentityPoolConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.get_identity_pool_configuration)
+        Gets the configuration settings of an identity pool.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.get_identity_pool_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#get_identity_pool_configuration)
         """
 
     def list_datasets(
-        self, *, IdentityPoolId: str, IdentityId: str, NextToken: str = None, MaxResults: int = None
+        self, *, IdentityPoolId: str, IdentityId: str, NextToken: str = ..., MaxResults: int = ...
     ) -> ListDatasetsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.list_datasets)
+        Lists datasets for an identity.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.list_datasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#list_datasets)
         """
 
     def list_identity_pool_usage(
-        self, *, NextToken: str = None, MaxResults: int = None
+        self, *, NextToken: str = ..., MaxResults: int = ...
     ) -> ListIdentityPoolUsageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.list_identity_pool_usage)
+        Gets a list of identity pools registered with Cognito.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.list_identity_pool_usage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#list_identity_pool_usage)
         """
 
@@ -174,13 +210,16 @@ class CognitoSyncClient:
         IdentityPoolId: str,
         IdentityId: str,
         DatasetName: str,
-        LastSyncCount: int = None,
-        NextToken: str = None,
-        MaxResults: int = None,
-        SyncSessionToken: str = None
+        LastSyncCount: int = ...,
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        SyncSessionToken: str = ...
     ) -> ListRecordsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.list_records)
+        Gets paginated records, optionally changed after a particular sync count for a
+        dataset and identity.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.list_records)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#list_records)
         """
 
@@ -188,13 +227,17 @@ class CognitoSyncClient:
         self, *, IdentityPoolId: str, IdentityId: str, Platform: PlatformType, Token: str
     ) -> RegisterDeviceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.register_device)
+        Registers a device to receive push sync notifications.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.register_device)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#register_device)
         """
 
-    def set_cognito_events(self, *, IdentityPoolId: str, Events: Dict[str, str]) -> None:
+    def set_cognito_events(self, *, IdentityPoolId: str, Events: Mapping[str, str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.set_cognito_events)
+        Sets the AWS Lambda function for a given event type for an identity pool.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.set_cognito_events)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#set_cognito_events)
         """
 
@@ -202,11 +245,13 @@ class CognitoSyncClient:
         self,
         *,
         IdentityPoolId: str,
-        PushSync: "PushSyncTypeDef" = None,
-        CognitoStreams: "CognitoStreamsTypeDef" = None
+        PushSync: "PushSyncTypeDef" = ...,
+        CognitoStreams: "CognitoStreamsTypeDef" = ...
     ) -> SetIdentityPoolConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.set_identity_pool_configuration)
+        Sets the necessary configuration for push sync.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.set_identity_pool_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#set_identity_pool_configuration)
         """
 
@@ -214,7 +259,10 @@ class CognitoSyncClient:
         self, *, IdentityPoolId: str, IdentityId: str, DatasetName: str, DeviceId: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.subscribe_to_dataset)
+        Subscribes to receive notifications when a dataset is modified by another
+        device.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.subscribe_to_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#subscribe_to_dataset)
         """
 
@@ -222,7 +270,10 @@ class CognitoSyncClient:
         self, *, IdentityPoolId: str, IdentityId: str, DatasetName: str, DeviceId: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.unsubscribe_from_dataset)
+        Unsubscribes from receiving notifications when a dataset is modified by another
+        device.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.unsubscribe_from_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#unsubscribe_from_dataset)
         """
 
@@ -233,11 +284,13 @@ class CognitoSyncClient:
         IdentityId: str,
         DatasetName: str,
         SyncSessionToken: str,
-        DeviceId: str = None,
-        RecordPatches: List[RecordPatchTypeDef] = None,
-        ClientContext: str = None
+        DeviceId: str = ...,
+        RecordPatches: Sequence["RecordPatchTypeDef"] = ...,
+        ClientContext: str = ...
     ) -> UpdateRecordsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.update_records)
+        Posts updates to records and adds and deletes records for a dataset and user.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cognito-sync.html#CognitoSync.Client.update_records)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#update_records)
         """
